ExecutableAddressResponse

Struct ExecutableAddressResponse 

#[repr(C)]
pub struct ExecutableAddressResponse { /* private fields */ }
A response to a executable address request.

This can be used to convert a virtual address within the executable to a physical address like so:

let phys_addr = virt_addr - virtual_base + physical_base;

Implementations

Source

impl ExecutableAddressResponse

pub fn revision(&self) -> u64

Returns the revision of the response.

pub fn physical_base(&self) -> u64

Returns the base address of the executable in physical memory.

pub fn virtual_base(&self) -> u64

Returns the base address of the executable in virtual memory.