#[repr(C)]pub struct ExecutableAddressResponse { /* private fields */ }Expand description
A response to a executable address request.
This can be used to convert a virtual address within the executable to a physical address like so:
let phys_addr = virt_addr - virtual_base + physical_base;Implementations
Sourceimpl ExecutableAddressResponse
impl ExecutableAddressResponse
Sourcepub fn physical_base(&self) -> u64
pub fn physical_base(&self) -> u64
Returns the base address of the executable in physical memory.
Sourcepub fn virtual_base(&self) -> u64
pub fn virtual_base(&self) -> u64
Returns the base address of the executable in virtual memory.